@@ -516,7 +516,7 @@ HEADER
                 elsif ($obj->{name} eq 'ARGV') {
                     $self->top_add("require Encode;");
                     $self->top_add(  qq{my \$$name = Sidef::Types::Array::Array->new}
-                                   . qq{(map {Sidef::Types::String::String->new(Encode::decode_utf8(\$_))} \@ARGV);});
+                                   . qq{([map {Sidef::Types::String::String->new(Encode::decode_utf8(\$_))} \@ARGV]);});
                 }
 
                 $code = $self->_dump_var($obj, $refaddr);
@@ -566,7 +566,8 @@ HEADER
                     if (exists $obj->{value}{kids}) {
                         chop $code;
                         my @kids = map {
-                            local $_->{type} = 'func';
+                            local $_->{type}   = 'func';
+                            local $_->{is_kid} = 1;
                             'do{' . $self->deparse_expr({self => $_}) . '}';
                         } @{$obj->{value}{kids}};
 
@@ -599,7 +600,17 @@ HEADER
                           . "\$$obj->{name}$refaddr\->{code}=Memoize::memoize(\$$obj->{name}${refaddr}->{code});\$$obj->{name}$refaddr}";
                     }
 
-                    if ($obj->{type} eq 'method') {
+                    if ($obj->{type} eq 'func' and not $obj->{is_kid}) {
+
+                        # Special "MAIN" function
+                        if ($obj->{name} eq 'MAIN') {
+                            $self->top_add('require Encode;');
+                            $code .=
+                              ";Sidef::Variable::GetOpt->new([map{Encode::decode_utf8(\$_)}\@ARGV],\$$obj->{name}$refaddr)";
+                        }
+
+                    }
+                    elsif ($obj->{type} eq 'method') {
 
                         # Special "AUTOLOAD" method
                         if ($obj->{name} eq 'AUTOLOAD') {
@@ -883,16 +894,7 @@ HEADER
 
                     # Make the last statement to be the return value
                     if ($is_function && @statements) {
-
-                        if ($statements[-1] =~ /^\@return = /) {
-
-                            # Make a minor improvement by removing the 'goto'
-                            $statements[-1] =~ s/;\h*goto END$refaddr\z//;
-                            $statements[-1] =~ s/^\@return = /return/;
-                        }
-                        else {
-                            $statements[-1] = 'return do{' . $statements[-1] . '}';
-                        }
+                        $statements[-1] = 'return do{' . $statements[-1] . '}';
                     }
 
                     $code .= join(';', @statements) . ($is_function ? (';' . "END$refaddr: \@return;") : '') . '}';
@@ -970,8 +972,8 @@ HEADER
             my ($sgn, $content) = $obj->_deparse;
             $code =
                 ($sgn == 2) ? $self->make_constant($ref, '_set_str',  "Number$refaddr", "'" . $content . "'")
-              : ($sgn >= 0) ? $self->make_constant($ref, '_new_uint', "Number$refaddr", "'" . $content . "'")
-              :               $self->make_constant($ref, '_new_int', "Number$refaddr", "'" . $content . "'");
+              : ($sgn >= 0) ? $self->make_constant($ref, '_set_uint', "Number$refaddr", "'" . $content . "'")
+              :               $self->make_constant($ref, '_set_int', "Number$refaddr", "'" . $content . "'");
         }
         elsif ($ref eq 'Sidef::Types::Number::Inf') {
             $code = $self->make_constant($ref, 'new', "Inf$refaddr");
@@ -1083,6 +1085,9 @@ HEADER
                 $code = $self->make_constant($ref, 'new', "Hash$refaddr");
             }
         }
+        elsif ($ref eq 'Sidef::Meta::PrefixMethod') {
+            $code = 'do{my($self,@args)=' . $self->deparse_args($obj->{expr}) . ';$self->' . $obj->{name} . '(@args)}';
+        }
         elsif ($ref eq 'Sidef::Types::Block::Do') {
             $code = 'do ' . $self->deparse_bare_block($obj->{block}{code});
         }
@@ -1322,7 +1327,7 @@ HEADER
                 if (exists $ind->{array}) {
                     my $indices = $self->_dump_indices($ind->{array});
 
-                    $code = '@{' . $code . '}';
+                    $code = '@{(' . $code . ')}';
 
                     if ($indices ne '') {
                         $code .= '['
@@ -1337,7 +1342,7 @@ HEADER
                     my $keys = $self->_dump_lookups($ind->{hash});
 
                     if ($keys eq '') {
-                        $code = '%{' . $code . '}';
+                        $code = '%{(' . $code . ')}';
                     }
                     else {
                         $code = '@{'
@@ -1352,7 +1357,7 @@ HEADER
 
                 if ($i < $limit) {
                     if ($expr->{ind}[$i + 1]{array}) {
-                        $code = "($code//=Sidef::Types::Array::Array->new)";
+                        $code = "($code//=Sidef::Types::Array::Array->new([]))";
                     }
                     else {
                         $code = "($code//=Sidef::Types::Hash::Hash->new)";
@@ -1379,7 +1384,7 @@ HEADER
                     if (exists $self->{function}) {
                         $code .= 'do{';
                         if (@{$call->{arg}}) {
-                            $code .= '@return = ' . $self->deparse_args(@{$call->{arg}}) . ';';    # don't edit this line!
+                            $code .= '@return=' . $self->deparse_args(@{$call->{arg}}) . ';';
                         }
                         $code .= 'goto ' . "END$self->{function}}";
                     }
