@@ -491,14 +491,14 @@ package Sidef::Types::Array::Array {
                 }
             }
 
-            return Sidef::Types::Number::Number->_new_uint($counter);
+            return Sidef::Types::Number::Number->_set_uint($counter);
         }
 
         foreach my $item (@{$self}) {
             $item eq $obj and $counter++;
         }
 
-        Sidef::Types::Number::Number->_new_uint($counter);
+        Sidef::Types::Number::Number->_set_uint($counter);
     }
 
     *count_by = \&count;
@@ -883,7 +883,7 @@ package Sidef::Types::Array::Array {
         my ($self, $code) = @_;
 
         foreach my $i (0 .. $#{$self}) {
-            $code->run(Sidef::Types::Number::Number->_new_uint($i));
+            $code->run(Sidef::Types::Number::Number->_set_uint($i));
         }
 
         $self;
@@ -895,7 +895,7 @@ package Sidef::Types::Array::Array {
         my ($self, $code) = @_;
 
         foreach my $i (0 .. $#{$self}) {
-            $code->run(Sidef::Types::Number::Number->_new_uint($i), $self->[$i]);
+            $code->run(Sidef::Types::Number::Number->_set_uint($i), $self->[$i]);
         }
 
         $self;
@@ -917,7 +917,7 @@ package Sidef::Types::Array::Array {
 
         my @arr;
         foreach my $i (0 .. $#{$self}) {
-            CORE::push(@arr, $code->run(Sidef::Types::Number::Number->_new_uint($i), $self->[$i]));
+            CORE::push(@arr, $code->run(Sidef::Types::Number::Number->_set_uint($i), $self->[$i]));
         }
 
         $self->new(\@arr);
@@ -959,7 +959,7 @@ package Sidef::Types::Array::Array {
 
         my @arr;
         foreach my $i (0 .. $#{$self}) {
-            CORE::push(@arr, $self->[$i]) if $code->run(Sidef::Types::Number::Number->_new_uint($i), $self->[$i]);
+            CORE::push(@arr, $self->[$i]) if $code->run(Sidef::Types::Number::Number->_set_uint($i), $self->[$i]);
         }
 
         $self->new(\@arr);
@@ -981,6 +981,38 @@ package Sidef::Types::Array::Array {
         $hash;
     }
 
+    sub match {
+        my ($self, $regex) = @_;
+
+        my %addr;
+
+        my $sub = sub {
+            my ($obj) = @_;
+
+            my $refaddr = Scalar::Util::refaddr($obj);
+
+            exists($addr{$refaddr})
+              && return Sidef::Types::Bool::Bool::FALSE;
+
+            undef $addr{$refaddr};
+
+            foreach my $item (@$obj) {
+                if (defined(my $sub = UNIVERSAL::can($item, 'match'))) {
+                    $sub->($item, $regex)
+                      && return Sidef::Types::Bool::Bool::TRUE;
+                }
+                elsif ("$item" =~ $regex->{regex}) {
+                    return Sidef::Types::Bool::Bool::TRUE;
+                }
+            }
+
+            Sidef::Types::Bool::Bool::FALSE;
+        };
+
+        local *Sidef::Types::Array::Array::match = $sub;
+        $sub->($_[0]);
+    }
+
     sub iter {
         my ($self) = @_;
 
@@ -1005,7 +1037,7 @@ package Sidef::Types::Array::Array {
         }
 
         foreach my $key (keys %hash) {
-            $hash{$key} = Sidef::Types::Number::Number->_new_uint($hash{$key});
+            $hash{$key} = Sidef::Types::Number::Number->_set_uint($hash{$key});
         }
 
         Sidef::Types::Hash::Hash->new(%hash);
@@ -1020,7 +1052,7 @@ package Sidef::Types::Array::Array {
         }
 
         foreach my $key (keys %hash) {
-            $hash{$key} = Sidef::Types::Number::Number->_new_uint($hash{$key});
+            $hash{$key} = Sidef::Types::Number::Number->_set_uint($hash{$key});
         }
 
         Sidef::Types::Hash::Hash->new(%hash);
@@ -1090,14 +1122,14 @@ package Sidef::Types::Array::Array {
             if (ref($obj) eq 'Sidef::Types::Block::Block') {
                 foreach my $i (0 .. $#{$self}) {
                     $obj->run($self->[$i])
-                      && return Sidef::Types::Number::Number->_new_uint($i);
+                      && return Sidef::Types::Number::Number->_set_uint($i);
                 }
                 return Sidef::Types::Number::Number::MONE;
             }
 
             foreach my $i (0 .. $#{$self}) {
                 $self->[$i] eq $obj
-                  and return Sidef::Types::Number::Number->_new_uint($i);
+                  and return Sidef::Types::Number::Number->_set_uint($i);
             }
 
             return Sidef::Types::Number::Number::MONE;
@@ -1118,7 +1150,7 @@ package Sidef::Types::Array::Array {
             if (ref($obj) eq 'Sidef::Types::Block::Block') {
                 for (my $i = $#{$self} ; $i >= 0 ; $i--) {
                     $obj->run($self->[$i])
-                      && return Sidef::Types::Number::Number->_new_uint($i);
+                      && return Sidef::Types::Number::Number->_set_uint($i);
                 }
 
                 return Sidef::Types::Number::Number::MONE;
@@ -1126,7 +1158,7 @@ package Sidef::Types::Array::Array {
 
             for (my $i = $#{$self} ; $i >= 0 ; $i--) {
                 $self->[$i] eq $obj
-                  and return Sidef::Types::Number::Number->_new_uint($i);
+                  and return Sidef::Types::Number::Number->_set_uint($i);
             }
 
             return Sidef::Types::Number::Number::MONE;
@@ -1202,7 +1234,7 @@ package Sidef::Types::Array::Array {
 
     sub length {
         my ($self) = @_;
-        Sidef::Types::Number::Number->_new_uint(scalar @{$self});
+        Sidef::Types::Number::Number->_set_uint(scalar @{$self});
     }
 
     *len  = \&length;    # alias
@@ -1213,8 +1245,8 @@ package Sidef::Types::Array::Array {
             $end == -1 ? Sidef::Types::Number::Number::MONE
           : $end == 0  ? Sidef::Types::Number::Number::ZERO
           : $end == 1  ? Sidef::Types::Number::Number::ONE
-          : $end > 0   ? Sidef::Types::Number::Number->_new_uint($end)
-          :              Sidef::Types::Number::Number->_new_int($end);
+          : $end > 0   ? Sidef::Types::Number::Number->_set_uint($end)
+          :              Sidef::Types::Number::Number->_set_int($end);
     }
 
     *offset = \&end;
@@ -1245,14 +1277,14 @@ package Sidef::Types::Array::Array {
     sub range {
         my ($self) = @_;
         Sidef::Types::Range::RangeNumber->new(Sidef::Types::Number::Number::ZERO,
-                                              Sidef::Types::Number::Number->_new_int($#{$self}),
+                                              Sidef::Types::Number::Number->_set_int($#{$self}),
                                               Sidef::Types::Number::Number::ONE,
                                              );
     }
 
     sub indices {
         my ($self) = @_;
-        $self->new([map { Sidef::Types::Number::Number->_new_uint($_) } 0 .. $#{$self}]);
+        $self->new([map { Sidef::Types::Number::Number->_set_uint($_) } 0 .. $#{$self}]);
     }
 
     *keys = \&indices;
@@ -1260,7 +1292,7 @@ package Sidef::Types::Array::Array {
     sub pairs {
         my ($self) = @_;
         $self->new(
-            [map { Sidef::Types::Array::Pair->new(Sidef::Types::Number::Number->_new_uint($_), $self->[$_]) } 0 .. $#{$self}]);
+            [map { Sidef::Types::Array::Pair->new(Sidef::Types::Number::Number->_set_uint($_), $self->[$_]) } 0 .. $#{$self}]);
     }
 
     *kv = \&pairs;
@@ -1852,6 +1884,78 @@ package Sidef::Types::Array::Array {
 
     sub to_list { @{$_[0]} }
 
+    sub getopt {
+        my ($self, %opts) = @_;
+
+        state $x = require Getopt::Long;
+
+        my @argv = map { "$_" } @$self;
+        my @opts = CORE::keys %opts;
+
+        my %parsed;
+        Getopt::Long::GetOptionsFromArray(\@argv, \%parsed, @opts);
+
+        my %lookup = map {
+            my ($name) = Getopt::Long::ParseOptionSpec($_, \my %info);
+            defined($name) ? ($name => {obj => $opts{$_}, type => $info{$name}[0]}) : ();
+        } @opts;
+
+        foreach my $key (CORE::keys %parsed) {
+
+            my $rec  = $lookup{$key};
+            my $obj  = $rec->{obj};
+            my $type = $rec->{type};
+
+            if (ref($obj) eq 'REF' or ref($obj) eq 'SCALAR') {
+                my $ref = ref($$obj);
+
+                # Determine the type for undefined references
+                if ($ref eq '') {
+                    if ($type eq 'i' or $type eq 'f') {
+                        $ref = 'Sidef::Types::Number::Number';
+                    }
+                    elsif ($type eq '') {
+                        $ref = 'Sidef::Types::Bool::Bool';
+                    }
+                    else {
+                        $ref = 'Sidef::Types::String::String';
+                    }
+                }
+
+                if (   $ref eq 'Sidef::Types::String::String'
+                    or $ref eq 'Sidef::Types::Number::Number') {
+                    $$obj = $ref->new($parsed{$key});
+                }
+                elsif ($ref eq 'Sidef::Types::Bool::Bool') {
+                    $$obj =
+                      $parsed{$key}
+                      ? Sidef::Types::Bool::Bool::TRUE
+                      : Sidef::Types::Bool::Bool::FALSE;
+                }
+                else {
+                    if ($type eq '') {
+                        $$obj = $ref->new(
+                                          $parsed{$key}
+                                          ? Sidef::Types::Bool::Bool::TRUE
+                                          : Sidef::Types::Bool::Bool::FALSE
+                                         );
+                    }
+                    elsif ($type eq 'i' or $type eq 'f') {
+                        $$obj = $ref->new(Sidef::Types::Number::Number->new($parsed{$key}));
+                    }
+                    else {
+                        $$obj = $ref->new(Sidef::Types::String::String->new($parsed{$key}));
+                    }
+                }
+            }
+            else {
+                $obj->call();
+            }
+        }
+
+        $self->new([map { Sidef::Types::String::String->new($_) } @argv]);
+    }
+
     sub _dump {
 
         my %addr;    # keeps track of dumped objects
