@@ -12,8 +12,7 @@ package Sidef::Types::Number::Inf {
       q{0+}   => sub { 'inf' },
       q{""}   => sub { 'Inf' };
 
-    my $INF = Math::GMPq::Rmpq_init();
-    Math::GMPq::Rmpq_set_ui($INF, 1, 0);
+    Math::GMPq::Rmpq_set_ui((state $INF = Math::GMPq::Rmpq_init_nobless()), 1, 0);
 
     use constant INF => bless(\$INF, __PACKAGE__);
 
@@ -63,52 +62,88 @@ package Sidef::Types::Number::Inf {
 
     *is_inf = \&is_pos;
 
-    sub is_ninf { Sidef::Types::Bool::Bool::FALSE }
+    sub is_real { Sidef::Types::Bool::Bool::FALSE }
 
-    *is_nan    = \&is_ninf;
-    *is_neg    = \&is_ninf;
-    *is_prime  = \&is_ninf;
-    *is_square = \&is_ninf;
-    *is_sqr    = \&is_ninf;
-    *is_power  = \&is_ninf;
-    *is_pow    = \&is_ninf;
-    *is_div    = \&is_ninf;
-    *is_even   = \&is_ninf;
-    *is_odd    = \&is_ninf;
-    *divides   = \&is_ninf;
-    *is_real   = \&is_ninf;
-    *is_zero   = \&is_ninf;
-    *is_one    = \&is_ninf;
-    *is_mone   = \&is_ninf;
+    *is_nan            = \&is_real;
+    *is_neg            = \&is_real;
+    *is_prime          = \&is_real;
+    *is_prob_prime     = \&is_real;
+    *is_prov_prime     = \&is_real;
+    *is_square         = \&is_real;
+    *is_sqr            = \&is_real;
+    *is_power          = \&is_real;
+    *is_pow            = \&is_real;
+    *is_div            = \&is_real;
+    *is_even           = \&is_real;
+    *is_odd            = \&is_real;
+    *divides           = \&is_real;
+    *is_ninf           = \&is_real;
+    *is_zero           = \&is_real;
+    *is_one            = \&is_real;
+    *is_mone           = \&is_real;
+    *is_square_free    = \&is_real;
+    *is_prime_power    = \&is_real;
+    *is_primitive_root = \&is_real;
 
     sub nan { Sidef::Types::Number::Nan::NAN }
 
-    *mod         = \&nan;
-    *imod        = \&nan;
-    *fmod        = \&nan;
-    *bin         = \&nan;
-    *modpow      = \&nan;
-    *expmod      = \&nan;
-    *powmod      = \&nan;
-    *modinv      = \&nan;
-    *invmod      = \&nan;
-    *and         = \&nan;
-    *or          = \&nan;
-    *xor         = \&nan;
-    *legendre    = \&nan;
-    *jacobi      = \&nan;
-    *kronecker   = \&nan;
-    *gcd         = \&nan;
-    *lcm         = \&nan;
-    *next_power2 = \&nan;
-    *next_pow2   = \&nan;
-    *next_pow    = \&nan;
-    *next_power  = \&nan;
-    *digit       = \&nan;
-    *bernreal    = \&nan;
-    *bernfrac    = \&nan;
-    *bern        = \&nan;
-    *valuation   = \&nan;
+    *mod               = \&nan;
+    *imod              = \&nan;
+    *fmod              = \&nan;
+    *bin               = \&nan;
+    *modpow            = \&nan;
+    *expmod            = \&nan;
+    *powmod            = \&nan;
+    *modinv            = \&nan;
+    *invmod            = \&nan;
+    *and               = \&nan;
+    *or                = \&nan;
+    *xor               = \&nan;
+    *legendre          = \&nan;
+    *jacobi            = \&nan;
+    *kronecker         = \&nan;
+    *gcd               = \&nan;
+    *lcm               = \&nan;
+    *next_power2       = \&nan;
+    *next_pow2         = \&nan;
+    *next_pow          = \&nan;
+    *next_power        = \&nan;
+    *next_prime        = \&nan;
+    *prev_prime        = \&nan;
+    *digit             = \&nan;
+    *bernreal          = \&nan;
+    *bernfrac          = \&nan;
+    *bern              = \&nan;
+    *bernoulli         = \&nan;
+    *valuation         = \&nan;
+    *popcount          = \&nan;
+    *mobius            = \&nan;
+    *moebius           = \&nan;
+    *sigma             = \&nan;
+    *sigma0            = \&nan;
+    *omega             = \&nan;
+    *big_omega         = \&nan;
+    *prime_root        = \&nan;
+    *prime_power       = \&nan;
+    *totient           = \&nan;
+    *euler_phi         = \&nan;
+    *euler_totient     = \&nan;
+    *jordan_totient    = \&nan;
+    *carmichael_lambda = \&nan;
+    *liouville         = \&nan;
+    *exp_mangoldt      = \&nan;
+    *stirling          = \&nan;
+    *stirling2         = \&nan;
+    *stirling3         = \&nan;
+    *znorder           = \&nan;
+    *znprimroot        = \&nan;
+    *ramanujan_tau     = \&nan;
+    *prime_count       = \&nan;
+
+    *harm     = \&inf;
+    *harmonic = \&inf;
+    *harmfrac = \&inf;
+    *harmreal = \&inf;
 
     sub as_bin {
         state $x = Sidef::Types::String::String->new;
@@ -118,14 +153,32 @@ package Sidef::Types::Number::Inf {
     *as_hex = \&as_bin;
 
     sub digits {
-        Sidef::Types::Array::Array->new;
+        Sidef::Types::Array::Array->new([]);
     }
 
+    *factor       = \&digits;
+    *factors      = \&digits;
+    *factor_pairs = \&digits;
+    *primes       = \&digits;
+    *divisors     = \&digits;
+
     sub divmod {
         my ($x, $y) = @_;
         ($x->div($y), Sidef::Types::Number::Nan::NAN);
     }
 
+    sub isqrtrem {
+        my ($x) = @_;
+        my $sqrt = $x->isqrt;
+        ($sqrt, $x->sub($sqrt));
+    }
+
+    sub irootrem {
+        my ($x, $y) = @_;
+        my $root = $x->iroot($y);
+        ($root, $x->sub($root));
+    }
+
     sub ninf {
         state $x = Sidef::Types::Number::Ninf->new;
     }
@@ -194,6 +247,7 @@ package Sidef::Types::Number::Inf {
     *double_factorial = \&inf;
     *dfac             = \&inf;
     *primorial        = \&inf;
+    *pn_primorial     = \&inf;
     *fibonacci        = \&inf;
     *lucas            = \&inf;
     *shift_left       = \&inf;
@@ -208,7 +262,8 @@ package Sidef::Types::Number::Inf {
     *grad2deg         = \&inf;
     *round            = \&inf;
     *roundf           = \&inf;
-    *popcount         = \&nan;
+    *partitions       = \&inf;
+    *bell             = \&inf;
 
     sub zero { Sidef::Types::Number::Number::ZERO }
 
@@ -479,6 +534,12 @@ package Sidef::Types::Number::Inf {
         *{__PACKAGE__ . '::' . '//'}  = \&div;
         *{__PACKAGE__ . '::' . 'Γ'}  = \&inf;
         *{__PACKAGE__ . '::' . 'Ψ'}  = \&inf;
+        *{__PACKAGE__ . '::' . 'ϕ'}  = \&euler_totient;
+        *{__PACKAGE__ . '::' . 'σ'}  = \&sigma;
+        *{__PACKAGE__ . '::' . 'Ω'}  = \&big_omega;
+        *{__PACKAGE__ . '::' . 'ω'}  = \&omega;
+        *{__PACKAGE__ . '::' . 'ζ'}  = \&zeta;
+        *{__PACKAGE__ . '::' . 'μ'}  = \&mobius;
     }
 }
 
