@@ -12,8 +12,7 @@ package Sidef::Types::Number::Ninf {
       q{0+}   => sub { -'inf' },
       q{""}   => sub { '-Inf' };
 
-    my $NINF = Math::GMPq::Rmpq_init();
-    Math::GMPq::Rmpq_set_si($NINF, -1, 0);
+    Math::GMPq::Rmpq_set_si((state $NINF = Math::GMPq::Rmpq_init_nobless()), -1, 0);
 
     use constant NINF => bless(\$NINF, __PACKAGE__);
 
@@ -59,21 +58,6 @@ package Sidef::Types::Number::Ninf {
 
     sub is_pos { Sidef::Types::Bool::Bool::FALSE }
 
-    *is_nan    = \&is_pos;
-    *is_prime  = \&is_pos;
-    *is_square = \&is_pos;
-    *is_sqr    = \&is_pos;
-    *is_power  = \&is_pos;
-    *is_pow    = \&is_pos;
-    *is_div    = \&is_pos;
-    *is_even   = \&is_pos;
-    *is_odd    = \&is_pos;
-    *divides   = \&is_pos;
-    *is_real   = \&is_pos;
-    *is_zero   = \&is_pos;
-    *is_one    = \&is_pos;
-    *is_mone   = \&is_pos;
-
     sub is_neg { Sidef::Types::Bool::Bool::TRUE }
 
     *is_inf  = \&is_neg;
@@ -86,40 +70,20 @@ package Sidef::Types::Number::Ninf {
     *digamma          = \&nan;
     *lngamma          = \&nan;
     *zeta             = \&nan;
-    *fmod             = \&nan;
-    *mod              = \&nan;
-    *imod             = \&nan;
-    *bin              = \&nan;
-    *modpow           = \&nan;
-    *expmod           = \&nan;
-    *powmod           = \&nan;
-    *modinv           = \&nan;
-    *invmod           = \&nan;
-    *and              = \&nan;
-    *or               = \&nan;
-    *xor              = \&nan;
     *factorial        = \&nan;
     *fac              = \&nan;
     *double_factorial = \&nan;
     *dfac             = \&nan;
     *primorial        = \&nan;
+    *pn_primorial     = \&nan;
     *fibonacci        = \&nan;
-    *legendre         = \&nan;
-    *jacobi           = \&nan;
-    *kronecker        = \&nan;
     *lucas            = \&nan;
-    *gcd              = \&nan;
-    *lcm              = \&nan;
-    *next_power2      = \&nan;
-    *next_pow2        = \&nan;
-    *next_pow         = \&nan;
-    *next_power       = \&nan;
-    *digit            = \&nan;
-    *bernreal         = \&nan;
-    *bernfrac         = \&nan;
-    *bern             = \&nan;
-    *popcount         = \&nan;
-    *valuation        = \&nan;
+    *harm             = \&nan;
+    *harmonic         = \&nan;
+    *harmfrac         = \&nan;
+    *harmreal         = \&nan;
+    *partitions       = \&nan;
+    *bell             = \&nan;
 
     sub inf { Sidef::Types::Number::Inf::INF }
 
@@ -383,7 +347,7 @@ package Sidef::Types::Number::Ninf {
     *commify = \&dump;
 
     sub of {
-        Sidef::Types::Array::Array->new();
+        Sidef::Types::Array::Array->new([]);
     }
 
     *defs = \&of;
@@ -413,11 +377,7 @@ package Sidef::Types::Number::Ninf {
         *{__PACKAGE__ . '::' . '*'}   = \&mul;
         *{__PACKAGE__ . '::' . '/'}   = \&div;
         *{__PACKAGE__ . '::' . '÷'}  = \&div;
-        *{__PACKAGE__ . '::' . '%'}   = \&mod;
         *{__PACKAGE__ . '::' . '**'}  = \&pow;
-        *{__PACKAGE__ . '::' . '&'}   = \&and;
-        *{__PACKAGE__ . '::' . '|'}   = \&or;
-        *{__PACKAGE__ . '::' . '^'}   = \&xor;
         *{__PACKAGE__ . '::' . '++'}  = \&inc;
         *{__PACKAGE__ . '::' . '--'}  = \&dec;
         *{__PACKAGE__ . '::' . '=='}  = \&eq;
@@ -431,13 +391,13 @@ package Sidef::Types::Number::Ninf {
         *{__PACKAGE__ . '::' . '≤'} = \&le;
         *{__PACKAGE__ . '::' . '<=>'} = \&cmp;
         *{__PACKAGE__ . '::' . '!'}   = \&factorial;
-        *{__PACKAGE__ . '::' . '%%'}  = \&is_div;
         *{__PACKAGE__ . '::' . '~'}   = \&not;
         *{__PACKAGE__ . '::' . '>>'}  = \&shift_right;
         *{__PACKAGE__ . '::' . '<<'}  = \&shift_left;
         *{__PACKAGE__ . '::' . '//'}  = \&div;
         *{__PACKAGE__ . '::' . 'Γ'}  = \&nan;
         *{__PACKAGE__ . '::' . 'Ψ'}  = \&nan;
+        *{__PACKAGE__ . '::' . 'ζ'}  = \&zeta;
     }
 }
 
