@@ -304,7 +304,7 @@ package Sidef::Types::Range::Range {
                 ++$count if $arg->run($obj);
             }
 
-            return Sidef::Types::Number::Number->_new_uint($count);
+            return Sidef::Types::Number::Number->_set_uint($count);
         }
 
         $self->contains($arg)
