@@ -389,7 +389,7 @@ package Sidef::Types::String::String {
 
     sub index {
         my ($self, $substr, $pos) = @_;
-        Sidef::Types::Number::Number->_new_int(
+        Sidef::Types::Number::Number->_set_int(
                                                defined($pos)
                                                ? CORE::index($$self, "$substr", CORE::int($pos))
                                                : CORE::index($$self, "$substr")
@@ -398,7 +398,7 @@ package Sidef::Types::String::String {
 
     sub rindex {
         my ($self, $substr, $pos) = @_;
-        Sidef::Types::Number::Number->_new_int(
+        Sidef::Types::Number::Number->_set_int(
                                                defined($pos)
                                                ? CORE::rindex($$self, "$substr", CORE::int($pos))
                                                : CORE::rindex($$self, "$substr")
@@ -409,7 +409,7 @@ package Sidef::Types::String::String {
         my ($self) = @_;
         $$self eq ''
           ? Sidef::Types::Number::Nan::NAN
-          : Sidef::Types::Number::Number->_new_uint(CORE::ord($$self));
+          : Sidef::Types::Number::Number->_set_uint(CORE::ord($$self));
     }
 
     sub reverse {
@@ -627,7 +627,7 @@ package Sidef::Types::String::String {
         Sidef::Types::Array::Array->new(
             [
              map {
-                 Sidef::Types::Number::Number->_new_uint(CORE::ord(bytes::substr($string, $_, 1)))
+                 Sidef::Types::Number::Number->_set_uint(CORE::ord(bytes::substr($string, $_, 1)))
                } 0 .. bytes::length($string) - 1
             ]
         );
@@ -640,7 +640,7 @@ package Sidef::Types::String::String {
 
         state $x = require bytes;
         foreach my $i (0 .. bytes::length($string) - 1) {
-            $code->run(Sidef::Types::Number::Number->_new_uint(CORE::ord bytes::substr($string, $i, 1)));
+            $code->run(Sidef::Types::Number::Number->_set_uint(CORE::ord bytes::substr($string, $i, 1)));
         }
 
         $self;
@@ -812,7 +812,7 @@ package Sidef::Types::String::String {
     }
 
     sub chars_length {
-        Sidef::Types::Number::Number->_new_uint(CORE::length(${$_[0]}));
+        Sidef::Types::Number::Number->_set_uint(CORE::length(${$_[0]}));
     }
 
     *len       = \&chars_length;
@@ -821,7 +821,7 @@ package Sidef::Types::String::String {
     *size      = \&chars_length;
 
     sub graphs_length {
-        Sidef::Types::Number::Number->_new_uint(scalar(() = ${$_[0]} =~ /\X/g));
+        Sidef::Types::Number::Number->_set_uint(scalar(() = ${$_[0]} =~ /\X/g));
     }
 
     *graphs_len = \&graphs_length;
@@ -830,7 +830,7 @@ package Sidef::Types::String::String {
         my ($self) = @_;
 
         state $x = require bytes;
-        Sidef::Types::Number::Number->_new_uint(bytes::length($$self));
+        Sidef::Types::Number::Number->_set_uint(bytes::length($$self));
     }
 
     *bytes_len = \&bytes_length;
@@ -856,7 +856,7 @@ package Sidef::Types::String::String {
             }
         }
 
-        Sidef::Types::Number::Number->_new_int($d[-1][-1]);
+        Sidef::Types::Number::Number->_set_int($d[-1][-1]);
     }
 
     *lev   = \&levenshtein;
@@ -963,18 +963,18 @@ package Sidef::Types::String::String {
         if (ref($arg) eq 'Sidef::Types::Regex::Regex') {
             my $regex = $arg->{regex};
             ++$counter while $s =~ /$regex/g;
-            return Sidef::Types::Number::Number->_new_uint($counter);
+            return Sidef::Types::Number::Number->_set_uint($counter);
         }
         elsif (ref($arg) eq 'Sidef::Types::Block::Block') {
             foreach my $char (split //, $s) {
                 ++$counter if $arg->run(bless(\$char, __PACKAGE__));
             }
-            return Sidef::Types::Number::Number->_new_uint($counter);
+            return Sidef::Types::Number::Number->_set_uint($counter);
         }
 
         my $ss = "$arg";
         ++$counter while $s =~ /\Q$ss\E/g;
-        Sidef::Types::Number::Number->_new_uint($counter);
+        Sidef::Types::Number::Number->_set_uint($counter);
     }
 
     sub overlaps {
