@@ -126,7 +126,7 @@ sub process_file {
 
         next if $sub eq 'get_value';
         next if $sub =~ /^[(_]/;
-        next if $sub =~ /^([[:upper:]])/;
+        next if $sub =~ /^[[:upper:]]./;
         next if exists $ignored_subs{$sub};
 
         my $code;
